package com.ruoyi.web.controller.oa;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.SnowFlake;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.oa.domain.CmcContractMeeting;
import com.ruoyi.oa.service.ICmcContractMeetingService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * cmc合同会审Controller
 * 
 * @author cmc
 * @date 2024-04-19
 */
@RestController
@RequestMapping("/oa/contractMeeting")
public class CmcContractMeetingController extends BaseController
{
    @Autowired
    private ICmcContractMeetingService cmcContractMeetingService;

    /**
     * 查询cmc合同会审列表
     */
    @GetMapping("/list")
    public TableDataInfo list(CmcContractMeeting cmcContractMeeting)
    {
        startPage();
        List<CmcContractMeeting> list = cmcContractMeetingService.selectCmcContractMeetingList(cmcContractMeeting);
        return getDataTable(list);
    }

    /**
     * 导出cmc合同会审列表
     */
    @Log(title = "cmc合同会审", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, CmcContractMeeting cmcContractMeeting)
    {
        List<CmcContractMeeting> list = cmcContractMeetingService.selectCmcContractMeetingList(cmcContractMeeting);
        ExcelUtil<CmcContractMeeting> util = new ExcelUtil<CmcContractMeeting>(CmcContractMeeting.class);
        util.exportExcel(response, list, "cmc合同会审数据");
    }

    /**
     * 获取cmc合同会审详细信息
     */
    @GetMapping(value = "/{contractId}")
    public AjaxResult getInfo(@PathVariable("contractId") String contractId)
    {
        return success(cmcContractMeetingService.selectCmcContractMeetingByContractId(contractId));
    }

    /**
     * 新增cmc合同会审
     */
    @Log(title = "cmc合同会审", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody CmcContractMeeting cmcContractMeeting)
    {
        cmcContractMeeting.setMeetingId(new SnowFlake().generateId());
        return toAjax(cmcContractMeetingService.insertCmcContractMeeting(cmcContractMeeting));
    }

    /**
     * 修改cmc合同会审
     */
    @Log(title = "cmc合同会审", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody CmcContractMeeting cmcContractMeeting)
    {
        return toAjax(cmcContractMeetingService.updateCmcContractMeeting(cmcContractMeeting));
    }

    /**
     * 删除cmc合同会审
     */
    @Log(title = "cmc合同会审", businessType = BusinessType.DELETE)
	@DeleteMapping("/{contractIds}")
    public AjaxResult remove(@PathVariable String[] contractIds)
    {
        return toAjax(cmcContractMeetingService.deleteCmcContractMeetingByContractIds(contractIds));
    }
}
